@@ -23,7 +23,7 @@ bool debug_z = false;
 
 void logEvent(const XEvent &xev) {
     switch (xev.type) {
-#if 1
+#if 0
     case CreateNotify:
         msg("window=0x%lX: create serial=%10d parent=0x%lX, (%d:%d-%dx%d) border_width=%d, override_redirect=%s",
             xev.xcreatewindow.window,
@@ -46,7 +46,7 @@ void logEvent(const XEvent &xev) {
     case DestroyNotify:
         break;
 #endif
-#if 1
+#if 0
     case MapRequest:
         msg("window=0x%lX: mapRequest serial=%10d parent=0x%lX",
             xev.xmaprequest.window,
@@ -79,7 +79,7 @@ void logEvent(const XEvent &xev) {
     case UnmapNotify:
         break;
 #endif
-#if 1
+#if 0
     case ConfigureRequest:
         msg("window=0x%lX: %s configureRequest serial=%10d parent=0x%lX, (%d:%d-%dx%d) border_width=%d, above=0x%lX, detail=%d, value_mask=0x%lX",
             xev.xconfigurerequest.window,
@@ -126,7 +126,7 @@ void logEvent(const XEvent &xev) {
         break;
 #endif
 
-#if 1
+#if 0
     case ReparentNotify:
         msg("window=0x%lX: reparentNotify serial=%10d event=0x%lX, parent=0x%lX, (%d:%d), override_redirect=%s",
             xev.xreparent.window,
@@ -168,7 +168,7 @@ void logEvent(const XEvent &xev) {
     case VisibilityNotify:
         break;
 #endif
-#if 1
+#if 0
     case ClientMessage:
         msg("window=0x%lX: clientMessage message_type=0x%lX format=%d",
             xev.xclient.window,
@@ -227,12 +227,13 @@ void logEvent(const XEvent &xev) {
     case MotionNotify:
         break;
 #endif
-#if 0
+#if 1
     case EnterNotify:
     case LeaveNotify:
-        msg("window=0x%lX: %s root=0x%lX, subwindow=0x%lX, time=%ld, (%d:%d %d:%d) mode=%d detail=%d same_screen=%s, focus=%s state=0x%X",
+        msg("window=0x%lX: %s serial=%10d root=0x%lX, subwindow=0x%lX, time=%ld, (%d:%d %d:%d) mode=%d detail=%d same_screen=%s, focus=%s state=0x%X",
             xev.xcrossing.window,
             (xev.type == EnterNotify) ? "enterNotify" : "leaveNotify",
+            xev.xany.serial,
             xev.xcrossing.root,
             xev.xcrossing.subwindow,
             xev.xcrossing.time,
@@ -249,7 +250,7 @@ void logEvent(const XEvent &xev) {
     case LeaveNotify:
         break;
 #endif
-#if 0
+#if 1
     case KeyPress:
     case KeyRelease:
         msg("window=0x%lX: %s root=0x%lX, subwindow=0x%lX, time=%ld, (%d:%d %d:%d) state=0x%X keycode=0x%x same_screen=%s",
@@ -264,7 +265,12 @@ void logEvent(const XEvent &xev) {
             xev.xkey.keycode,
             xev.xkey.same_screen ? "True" : "False");
         break;
-
+#else
+    case KeyPress:
+    case KeyRelease:
+        break;
+#endif
+#if 0
     case Expose:
         msg("window=0x%lX: expose (%d:%d-%dx%d) count=%d",
             xev.xexpose.window,
@@ -272,8 +278,6 @@ void logEvent(const XEvent &xev) {
             xev.xexpose.count);
         break;
 #else
-    case KeyPress:
-    case KeyRelease:
     case Expose:
         break;
 #endif
