@@ -137,7 +137,7 @@ void AboutDlg::showFocused() {
         getFrame()->setNormalPositionOuter(
             dx + dw / 2 - getFrame()->width() / 2,
             dy + dh / 2 - getFrame()->height() / 2);
-        getFrame()->activate(true);
+        getFrame()->activateWindow(true);
     }
 }
 
