@@ -55,6 +55,9 @@ extern YAction *actionHelp;
 extern YAction *actionLicense;
 extern YAction *actionRun;
 extern YAction *actionExit;
+extern YAction *actionFocusClickToFocus;
+extern YAction *actionFocusMouseSloppy;
+extern YAction *actionFocusCustom;
 
 void initActions();
 
