@@ -11,8 +11,8 @@ public:
     YFrameButton(YWindow *parent, YFrameWindow *frame, YAction *action, YAction *action2 = 0);
     virtual ~YFrameButton();
 
-    virtual void paint(Graphics &g, int x, int y, unsigned int width, unsigned int height);
-    virtual void paintFocus(Graphics &g, int x, int y, unsigned int w, unsigned int h);
+    virtual void paint(Graphics &g, const YRect &r);
+    virtual void paintFocus(Graphics &g, const YRect &r);
     virtual void handleButton(const XButtonEvent &button);
     virtual void handleClick(const XButtonEvent &up, int count);
     virtual void handleBeginDrag(const XButtonEvent &down, const XMotionEvent &motion);
@@ -21,21 +21,21 @@ public:
     void setActions(YAction *action, YAction *action2 = 0);
     virtual void updatePopup();
 
-    YPixmap *getImage(int pn) const;
+    ref<YPixmap> getImage(int pn) const;
     YFrameWindow *getFrame() const { return fFrame; };
 private:
     YFrameWindow *fFrame;
     YAction *fAction;
     YAction *fAction2;
 };
-
-extern YPixmap *closePixmap[2];
-extern YPixmap *minimizePixmap[2];
-extern YPixmap *maximizePixmap[2];
-extern YPixmap *restorePixmap[2];
-extern YPixmap *hidePixmap[2];
-extern YPixmap *rollupPixmap[2];
-extern YPixmap *rolldownPixmap[2];
-extern YPixmap *depthPixmap[2];
+//changed robc
+extern ref<YPixmap> closePixmap[3];
+extern ref<YPixmap> minimizePixmap[3];
+extern ref<YPixmap> maximizePixmap[3];
+extern ref<YPixmap> restorePixmap[3];
+extern ref<YPixmap> hidePixmap[3];
+extern ref<YPixmap> rollupPixmap[3];
+extern ref<YPixmap> rolldownPixmap[3];
+extern ref<YPixmap> depthPixmap[3];
 
 #endif
