@@ -115,6 +115,7 @@ unsigned int ignore_enternotify_hack = 0; // credits to ahwm
 
 static void update_ignore_enternotify_hack(const XEvent &event) {
     ignore_enternotify_hack = event.xany.serial;
+    MSG(("ignore: %10d", ignore_enternotify_hack));
     if (xapp && xapp->display())
         XSync(xapp->display(), False);
 }
@@ -950,6 +951,15 @@ void YWindow::handleClientMessage(const XClientMessageEvent &message) {
         && message.data.l[0] == (long)_XA_WM_DELETE_WINDOW)
     {
         handleClose();
+    } else if (message.message_type == _XA_WM_PROTOCOLS
+        && message.format == 32
+        && message.data.l[0] == (long)_XA_WM_TAKE_FOCUS)
+    {
+        YWindow *w = getFocusWindow();
+        if (w) 
+            w->requestFocus();
+        else
+            requestFocus();
     } else if (message.message_type == XA_XdndEnter ||
                message.message_type == XA_XdndLeave ||
                message.message_type == XA_XdndPosition ||
