@@ -8,6 +8,7 @@
 #define SYSTEM_TRAY_CANCEL_MESSAGE 2
 
 class YXTrayProxy;
+class YXTray;
 
 class YXTrayNotifier {
 public:
@@ -16,7 +17,24 @@ protected:
     virtual ~YXTrayNotifier() {};
 };
 
-class YXTray: public YXEmbed {
+class YXTrayEmbedder: public YXEmbed {
+public:
+    YXTrayEmbedder(YXTray *tray, Window win);
+    ~YXTrayEmbedder();
+    virtual void paint(Graphics &g, const YRect &r);
+    virtual void handleConfigureRequest(const XConfigureRequestEvent &configureRequest);
+    virtual void destroyedClient(Window win);
+    void detach();
+    virtual void configure(const YRect &r, const bool resized);
+
+    Window client_handle() { return fDocked->handle(); }
+    YXEmbedClient *client() { return fDocked; }
+private:
+    YXTray *fTray;
+    YXEmbedClient *fDocked;
+};
+
+class YXTray: public YWindow {
 public:
     YXTray(YXTrayNotifier *notifier, bool internal, const char *atom, YWindow *aParent = 0);
     virtual ~YXTray();
@@ -29,13 +47,14 @@ public:
     void relayout();
 
     void trayRequestDock(Window win);
-    virtual void destroyedClient(Window win);
     void detachTray();
 
     bool kdeRequestDock(Window win);
+
+    void destroyedClient(Window win);
 private:
     YXTrayProxy *fTrayProxy;
-    YObjectArray<YXEmbedClient> fDocked;
+    YObjectArray<YXTrayEmbedder> fDocked;
     YXTrayNotifier *fNotifier;
     bool fInternal;
 };
